
import unittest

from scales import Scale


class ScalesTest(unittest.TestCase):

    def test_scaleHeight(self):
        note_height = Scale.get_height_of_note("C4")
        self.assertEqual(note_height, 60, "Scale height is {0}".format(note_height))
        note_height = Scale.get_height_of_note("C3")
        self.assertEqual(note_height, 48, "Scale height is {0}".format(note_height))

    def test_rootNotesList(self):
        self.assertEqual(Scale.get_root_notes()[0], "C2")
        self.assertEqual(len(Scale.get_root_notes()) % 12, 1)  # from C-C thus 12*n+1

    def test_scaleGeneration(self):
        scale = Scale.get_scale("Balaphone", 60, 5, "major", Scale.IONIAN)
        # check 3rd note is pitch E
        self.assertEqual(-800, scale[2][1])
        scale = Scale.get_scale("Balaphone", 60, 5, "minor", Scale.IONIAN)
        # check 3rd note is now pitch Eb
        self.assertEqual(-900, scale[2][1])

    def test_noteNaming(self):
        self.assertEqual("C4", Scale.get_note_name(60))

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-


# http://jenyay.net/Programming/WxSizer
import ConfigParser
import os
import wx
import wx.grid as gridlib

import hpd20
from scaledialog import SetScaleDialog

from instrumentname import get_instrument_pitch, get_instrument_name, get_complete_instrument_list, \
    get_instrument_name_with_index


class HpdForm(wx.Frame):

    def load_config(self):
        self.config = ConfigParser.RawConfigParser()
        self.config.add_section('Settings')
        self.config_filename = os.path.expanduser('~/.hpd.cfg')
        try:
            self.config.read(os.path.expanduser('~/.hpd.cfg'))
            self.default_kits_dir = self.config.get('Settings', 'kits_directory')
            self.default_backup_dir = self.config.get('Settings', 'backup_directory')
            self.current_kit = self.config.getint('Settings', 'current_kit')
        except:
            pass

    def __init__(self, file_name):
        self.default_kits_dir = ""
        self.default_backup_dir = ""
        self.current_kit = 1
        self.instrument_index_offset = 6
        self.invisible_color = wx.Colour(200, 200, 200)
        self.neutral_color = wx.Colour(230, 230, 230)
        self.o_colors = [wx.Colour(210, 210, 250), wx.Colour(235, 235, 255)]
        self.s_colors = [wx.Colour(210, 250, 210), wx.Colour(235, 255, 235)]
        self.m_colors = [wx.Colour(250, 210, 210), wx.Colour(255, 235, 235)]
        self.columns = ['Layer', 'fade', 'trigger', 'velo', 'mutgrp', 'mn/ply',
                        'Instrument', 'vol', 'cents', 'note', 'muff', 'color', 'swp', 'ambsend', 'pan']
        self.pad_names = ['M1 ◵', 'M2 ◶', 'M3 ◴', 'M4 ◷', 'M5 ●',
                          'S1', 'S2', 'S3', 'S4',
                          'S5', 'S6', 'S7', 'S8',
                          'D-Beam', 'Head', 'Rim', 'HH']
        self.layer_type = ['off', 'mix', 'velo mix', 'velo fade', 'velo sw']
        self.trigger_type = ['shot', 'gate', 'alt']

        self.load_config()
        wx.Frame.__init__(self, parent=None, title="hpd-20 Editor", size=(1200, 830))
        self.panel = wx.Panel(self)
        self.layout_menu()
        self.layout_kit_grid()
        self.main_param_sizer = wx.BoxSizer(wx.HORIZONTAL)
        file_name = self.select_memory_backup()
        self.hpd = hpd20.hpd(file_name)

        self.cb_kit = wx.ComboBox(self.panel, -1, choices=self.hpd.kits.get_list_of_kits(), style=wx.TE_PROCESS_ENTER|wx.CB_READONLY)
        self.cb_kit.Bind(wx.EVT_COMBOBOX, self.select_kit)
        self.cb_kit.SetSelection(self.current_kit)

        self.cb_kit_name = wx.TextCtrl(self.panel, size=(200, -1), value="current kit name", style=wx.TE_PROCESS_ENTER)
        self.cb_kit.Bind(wx.EVT_CHAR, self.change_kit_name)
        self.cb_kit_subname = wx.TextCtrl(self.panel, size=(200, -1), value="current kit sub name", style=wx.TE_PROCESS_ENTER)
        self.scale_dialog_button = wx.Button(self.panel, label="scale")
        self.scale_dialog_button.Bind(wx.EVT_BUTTON, self.OnSetScaleDialog)

        self.main_param_sizer.Add(self.cb_kit)
        self.main_param_sizer.Add(self.cb_kit_name)
        self.main_param_sizer.Add(self.cb_kit_subname)
        self.main_param_sizer.Add(self.scale_dialog_button)

        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.main_param_sizer)
        sizer.Add(self.kit_grid)
        self.panel.SetSizer(sizer)
        self.fill_kit(self.current_kit)


    def select_kit(self, event):
        self.retrieve_kit_values(self.current_kit)
        kit = self.cb_kit.GetCurrentSelection()
        self.fill_kit(kit)
        self.current_kit = kit
        self.config.set('Settings', 'current_kit', kit)
        with open(self.config_filename, 'wb') as configfile:
            self.config.write(configfile)

    def change_kit_name(self, event):
        pass

    def layout_menu(self):
        menuBar = wx.MenuBar()

        menu1 = wx.Menu()
        menuBar.Append(menu1, '&File')
        open_item = menu1.Append(wx.ID_OPEN, '&Open memory dump')

        self.Bind(wx.EVT_MENU, self.load_memory_backup, open_item)
        save_item = menu1.Append(wx.ID_SAVE, '&Save memory dump')
        self.Bind(wx.EVT_MENU, self.save_memory_backup, save_item)
        menu1.AppendSeparator()
        load_kit_item = menu1.Append(wx.ID_ANY, 'Load Kit (overwrites current)')
        self.Bind(wx.EVT_MENU, self.load_kit, load_kit_item)
        save_kit_item = menu1.Append(wx.ID_ANY, 'Save Kit')
        self.Bind(wx.EVT_MENU, self.save_kit, save_kit_item)
        menu1.AppendSeparator()
        menu1.Append(wx.ID_EXIT, 'Quit', 'Quit application')
        menu6 = wx.Menu()
        menuBar.Append(menu6, '&Tools')
        menu7 = wx.Menu()
        menuBar.Append(menu7, '&Macros')
        menu7.Append(wx.ID_ANY, 'Set Scale')
        menu7.Append(wx.ID_ANY, 'Pan')
        menu8 = wx.Menu()
        menuBar.Append(menu8, '&Help')

        self.SetMenuBar(menuBar)

    def layout_kit_grid(self):
        self.kit_grid = gridlib.Grid(self.panel)
        self.kit_grid.CreateGrid(len(self.pad_names)*2, len(self.columns))
        for i in range(len(self.columns)):
            self.kit_grid.SetColLabelValue(i, self.columns[i])
            self.kit_grid.SetColSize(i, 48)
        for i in range(len(self.pad_names)):
            self.kit_grid.SetRowSize(i, 24)
            self.kit_grid.SetRowLabelValue(i * 2, self.pad_names[i])
            self.kit_grid.SetRowLabelValue(i * 2+1, '')
            for col in range(len(self.columns)):
                if col == 6:
                    self.kit_grid.SetCellAlignment(i*2, col, wx.ALIGN_LEFT, wx.ALIGN_CENTRE)
                    self.kit_grid.SetCellAlignment(i*2+1, col, wx.ALIGN_LEFT, wx.ALIGN_CENTRE)
                elif col == 10:
                    self.kit_grid.SetCellAlignment(i * 2, col, wx.ALIGN_CENTRE, wx.ALIGN_CENTRE)
                    self.kit_grid.SetCellAlignment(i * 2 + 1, col, wx.ALIGN_CENTRE, wx.ALIGN_CENTRE)
                else:
                    self.kit_grid.SetCellAlignment(i * 2, col, wx.ALIGN_RIGHT, wx.ALIGN_CENTRE)
                    self.kit_grid.SetCellAlignment(i * 2 + 1, col, wx.ALIGN_RIGHT, wx.ALIGN_CENTRE)
                if self.pad_names[i][0] == 'M':
                    color = self.m_colors[i % 2]
                elif self.pad_names[i][0] == 'S':
                    color = self.s_colors[i % 2]
                else:
                    color = self.o_colors[i % 2]
                self.kit_grid.SetCellBackgroundColour(i*2, col, color)
                if col < 6:
                    self.kit_grid.SetCellBackgroundColour(i*2+1, col, self.neutral_color)
                else:
                    self.kit_grid.SetCellBackgroundColour(i*2+1, col, color)

        self.kit_grid.SetColSize(6, 200)
        self.kit_grid.SetColSize(0, 80)

    def retrieve_kit_values(self, kit):
        instr_index_offset = 6
        for i in range(17):
            pad = self.hpd.pads.get_pad(kit * hpd20.hpd.PADS_PER_KIT + i)
            layer = self.kit_grid.GetCellValue(i * 2, 0)
            pad.set_layer(self.layer_type.index(layer))
            pad.set_velofade(int(self.kit_grid.GetCellValue(i * 2, 1)))
            trigger_type = self.kit_grid.GetCellValue(i * 2, 2)
            pad.set_trigger(self.trigger_type.index(trigger_type))
            pad.set_fixvelo(int(self.kit_grid.GetCellValue(i * 2, 3)))
            pad.set_mute_group(int(self.kit_grid.GetCellValue(i * 2, 4)))
            pad.set_mono_poly(int(self.kit_grid.GetCellValue(i * 2, 5)))

            for instr in range(2):
                col_idx = i * 2 + instr
                pad.set_volume(instr, int(self.kit_grid.GetCellValue(col_idx, instr_index_offset+1)))
                pad.set_pitch(instr, int(self.kit_grid.GetCellValue(col_idx, instr_index_offset+2)))
                pad.set_muffling(instr, int(self.kit_grid.GetCellValue(col_idx, instr_index_offset+4)))
                pad.set_color(instr, int(self.kit_grid.GetCellValue(col_idx, instr_index_offset+5)))
                pad.set_sweep(instr, int(self.kit_grid.GetCellValue(col_idx, instr_index_offset+6)))
                pad.set_ambientsend(instr, int(self.kit_grid.GetCellValue(col_idx, instr_index_offset+7)))
                pad.set_pan(instr, int(self.kit_grid.GetCellValue(col_idx, instr_index_offset+8)))

    def fill_kit(self, kit):
        hpdkit = self.hpd.kits.get_kit(kit)
        self.cb_kit_name.SetLabel(hpdkit.main_name().strip())
        self.cb_kit_subname.SetLabel(hpdkit.sub_name().strip())

        instr_index_offset = 6
        for i in range(17):
            pad = self.hpd.pads.get_pad(kit * hpd20.hpd.PADS_PER_KIT + i)
            if pad.get_layer() == 0:
                for j in range(len(self.columns)):
                    self.kit_grid.SetCellTextColour(i * 2 + 1, j, self.invisible_color)
            else:
                for j in range(len(self.columns)):
                    self.kit_grid.SetCellTextColour(i * 2 + 1, j, wx.BLACK)
            self.kit_grid.SetCellValue(i * 2, 0, self.layer_type[pad.get_layer()])
            choice_editor = gridlib.GridCellChoiceEditor(self.layer_type, False)
            self.kit_grid.SetCellEditor(i * 2, 0, choice_editor)

            self.kit_grid.SetCellValue(i * 2, 1, str(pad.get_velofade()))
            self.kit_grid.SetCellValue(i * 2, 2, str(self.trigger_type[pad.get_trigger()]))
            choice_editor = gridlib.GridCellChoiceEditor(self.trigger_type, False)
            self.kit_grid.SetCellEditor(i * 2, 2, choice_editor)
            self.kit_grid.SetCellValue(i * 2, 3, str(pad.get_fixvelo()))
            self.kit_grid.SetCellValue(i * 2, 4, str(pad.get_mute_group()))
            self.kit_grid.SetCellEditor(i * 2, 4, gridlib.GridCellNumberEditor(0, 8))
            self.kit_grid.SetCellValue(i * 2, 5, str(pad.get_mono_poly()))
            for instr in range(2):
                col_idx = i * 2 + instr
                choice_editor = gridlib.GridCellChoiceEditor(get_complete_instrument_list(), False)
                #choice_editor.SetText(get_instrument_name(pad.get_patch(instr)))
                self.kit_grid.SetCellEditor(col_idx, instr_index_offset+0, choice_editor)
                self.kit_grid.SetCellValue(col_idx, instr_index_offset+0, get_instrument_name_with_index(pad.get_patch(instr)))
                self.kit_grid.SetCellValue(col_idx, instr_index_offset+1, str(pad.get_volume(instr)))
                self.kit_grid.SetCellEditor(col_idx, instr_index_offset+1, gridlib.GridCellNumberEditor(0, 100))
                pitch = pad.get_pitch(instr)
                self.kit_grid.SetCellValue(col_idx, instr_index_offset+2, str(pitch))
                self.kit_grid.SetCellEditor(col_idx, instr_index_offset+2, gridlib.GridCellNumberEditor(-2400, 2400))
                pitch = pitch + get_instrument_pitch(pad.get_patch(instr))
                real_note = hpd20.get_note_name((pitch+50) / 100)
                self.kit_grid.SetCellValue(col_idx, instr_index_offset+3, str(real_note))
                self.kit_grid.SetCellValue(col_idx, instr_index_offset+4, str(pad.get_muffling(instr)))
                self.kit_grid.SetCellEditor(col_idx, instr_index_offset+4, gridlib.GridCellNumberEditor(0, 100))
                self.kit_grid.SetCellValue(col_idx, instr_index_offset+5, str(pad.get_color(instr)))
                self.kit_grid.SetCellEditor(col_idx, instr_index_offset+5, gridlib.GridCellNumberEditor(-50, 50))
                self.kit_grid.SetCellValue(col_idx, instr_index_offset+6, str(pad.get_sweep(instr)))
                self.kit_grid.SetCellEditor(col_idx, instr_index_offset+6, gridlib.GridCellNumberEditor(-100, 100))
                self.kit_grid.SetCellValue(col_idx, instr_index_offset+7, str(pad.get_ambientsend(instr)))
                self.kit_grid.SetCellEditor(col_idx, instr_index_offset+7, gridlib.GridCellNumberEditor(0, 127))
                self.kit_grid.SetCellValue(col_idx, instr_index_offset+8, str(pad.get_pan(instr)))
                self.kit_grid.SetCellEditor(col_idx, instr_index_offset+8, gridlib.GridCellNumberEditor(-15, 15))


    def OnSetScaleDialog(self, e):
        scale_dialog = SetScaleDialog(None, title='Scale to Kit Dialog')
        scale_dialog.set_hpd(self.hpd, self.current_kit)
        scale_dialog.ShowModal()
        scale_dialog.Destroy()
        self.fill_kit(self.current_kit)

    def load_kit(self, event):
        openFileDialog = wx.FileDialog(self, "Load Kit to current set", self.default_kits_dir, "",
                                       "hpd-20 Kit (*.kit)|*.kit",
                                       wx.FD_OPEN | wx.FD_FILE_MUST_EXIST)
        openFileDialog.ShowModal()
        path = openFileDialog.GetPath()
        openFileDialog.Destroy()
        self.default_kits_dir = path
        self.config.set('Settings', 'kits_directory', os.path.dirname(path))
        with open(self.config_filename, 'wb') as configfile:
            self.config.write(configfile)
        self.fill_kit(self.current_kit)

    def save_kit(self, event):
        openFileDialog = wx.FileDialog(self, "Save Kit", self.default_kits_dir, "",
                                       "hpd-20 Kit (*.kit)|*.kit",
                                       wx.FD_SAVE | wx.FD_OVERWRITE_PROMPT)
        openFileDialog.ShowModal()
        path = openFileDialog.GetPath()
        openFileDialog.Destroy()
        self.default_kits_dir = path
        self.config.set('Settings', 'kits_directory', os.path.dirname(path))
        with open(self.config_filename, 'wb') as configfile:
            self.config.write(configfile)

    def select_memory_backup(self):
        openFileDialog = wx.FileDialog(self, "Open a memory dump", self.default_backup_dir, "",
                                       "hpd-20 Dump (*.HS0)|*.HS0",
                                       wx.FD_OPEN | wx.FD_FILE_MUST_EXIST)
        openFileDialog.ShowModal()
        path = openFileDialog.GetPath()
        openFileDialog.Destroy()
        return path

    def load_memory_backup(self, event):
        self.default_backup_dir = self.select_memory_backup()
        self.config.set('Settings', 'backup_directory', os.path.dirname(self.default_backup_dir))
        with open(self.config_filename, 'wb') as configfile:
            self.config.write(configfile)
        self.hpd = hpd20.hpd(str(self.default_backup_dir))
        self.fill_kit(self.current_kit)

    def save_memory_backup(self, event):
        saveFileDialog = wx.FileDialog(self, "Save memory dump as", self.default_backup_dir, "",
                                             "hpd-20 Dump (*.HS0)|*.HS0",
                                             wx.FD_SAVE | wx.FD_OVERWRITE_PROMPT)
        saveFileDialog.ShowModal()
        path = saveFileDialog.GetPath()
        saveFileDialog.Destroy()
        self.default_backup_dir = path
        self.config.set('Settings', 'backup_directory', os.path.dirname(path))
        with open(self.config_filename, 'wb') as configfile:
            self.config.write(configfile)
        self.hpd.save_file(str(path))

def run_main():
    app = wx.App(False)
    frame = HpdForm('Backup/BKUP-022.HS0asd')
    frame.Show()
    app.MainLoop()

if __name__ == "__main__":
    run_main()






class MemoryOp:

    @staticmethod
    def get_int8(memory_block, index):
        value = memory_block[index]
        if value > 127:
            return -(256 - value)
        return value

    @staticmethod
    def set_int8(memory_block, index, value):
        memory_block[index] = value & 0xff

    @staticmethod
    def get_unsigned_int8(memory_block, index):
        value = memory_block[index]
        return value

    @staticmethod
    def get_int16(memory_block, index):
        value = memory_block[index] * 256 + memory_block[index + 1]
        if value > 32767:
            return -(65536 - value)
        return value

    @staticmethod
    def set_int16(memory_block, index, value):
        memory_block[index] = (value >> 8) & 0xff
        memory_block[index + 1] = value & 0xff

    @staticmethod
    def get_unsigned_int16(memory_block, index):
        value = memory_block[index] * 256 + memory_block[index + 1]
        return value

    @staticmethod
    def set_unsigned_int16(memory_block, index, value):
        memory_block[index] = (value >> 8) & 0xff
        memory_block[index + 1] = value & 0xff

    @staticmethod
    def get_string(memory_block, index, size):
        return str(memory_block[index:index+size])

    @staticmethod
    def set_string(memory_block, index, string):
        memory_block[index:index+len(string)] = string



#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-

import unittest

from memoryops import MemoryOp


class ScalesTest(unittest.TestCase):
    @staticmethod
    def create_testblock():
        return bytearray([i % 256 for i in range(512)])

    def test_fetch8bit(self):
        test_block = ScalesTest.create_testblock()
        self.assertEqual(1, MemoryOp.get_unsigned_int8(test_block, 1))
        self.assertEqual(129, MemoryOp.get_unsigned_int8(test_block, 129))
        self.assertEqual(-1, MemoryOp.get_int8(test_block, 255))

    def test_write8bit(self):
        test_block = ScalesTest.create_testblock()
        MemoryOp.set_int8(test_block, 1, 2)
        self.assertEqual(2, MemoryOp.get_unsigned_int8(test_block, 1))
        MemoryOp.set_int8(test_block, 129, -6)
        self.assertEqual(250, MemoryOp.get_unsigned_int8(test_block, 129))
        self.assertEqual(-6, MemoryOp.get_int8(test_block, 129))

    def test_fetch16bit(self):
        test_block = ScalesTest.create_testblock()
        #0x01 0x02 = 256+2
        self.assertEqual(258, MemoryOp.get_unsigned_int16(test_block, 1))
        #0xfe 0xff = 65279
        self.assertEqual(65279, MemoryOp.get_unsigned_int16(test_block, 254))
        self.assertEqual(-257, MemoryOp.get_int16(test_block, 254))

    def test_write16bit(self):
        test_block = ScalesTest.create_testblock()
        MemoryOp.set_int16(test_block, 1, -2)
        self.assertEqual(-2, MemoryOp.get_int16(test_block, 1))
        MemoryOp.set_unsigned_int16(test_block, 1, 0x8990)
        self.assertEqual(0x8990, MemoryOp.get_unsigned_int16(test_block, 1))

    def test_fetch_string(self):
        test_block = ScalesTest.create_testblock()
        self.assertEqual("01234567", MemoryOp.get_string(test_block, 48, 8))

    def test_write_string(self):
        test_block = ScalesTest.create_testblock()
        MemoryOp.set_string(test_block, 48, "foobar??")
        self.assertEqual("foobar??", MemoryOp.get_string(test_block, 48, 8))
        MemoryOp.set_string(test_block, 54, "!!")
        self.assertEqual("foobar!!", MemoryOp.get_string(test_block, 48, 8))


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

import wx

from hpd20 import Semantics
from ethnic_scales import list_of_scales_with_n_notes
from instrumentname import get_instrument_name, get_instrument_pitch
from melodypadpattern import melody_pad_pattern
from scales import Scale
import wx.grid as gridlib

class SetScaleDialog(wx.Dialog):
    def __init__(self, *args, **kw):
        super(SetScaleDialog, self).__init__(*args, **kw)
        self.init_ui()
        self.SetSize((1024, 800))
        self.SetTitle("Set Scale to Kit Dialog")

    def set_hpd(self, hpd, current_kit):
        self.current_kit = current_kit
        self.hpd = hpd

    def init_ui(self):
        self.panel = wx.Panel(self)
        top_sizer = wx.BoxSizer(wx.VERTICAL)

        label_layer = wx.StaticText(self.panel,  label="A or B")
        self.cb_layer = wx.ComboBox(self.panel,  0, choices=['Instrument A', 'Instrument B'], style=wx.TE_PROCESS_ENTER | wx.CB_READONLY)
        # self.cb_layer.Bind(wx.EVT_COMBOBOX, self.select_layer)

        label_instrument = wx.StaticText(self.panel,  label="Instrument")
        msets = Scale.melodic_sets.keys()
        msets.sort()
        self.cb_instrument = wx.ComboBox(self.panel,  0, choices=msets, style=wx.TE_PROCESS_ENTER | wx.CB_READONLY)
        self.cb_instrument.Bind(wx.EVT_COMBOBOX, self.select_instrument)


        main_scale_scheme = ['well tempered']
        for i in range(4, 17):
            main_scale_scheme.append(str(i) + ' note scale (with octave)')
            main_scale_scheme.append(str(i) + ' note scale (no octave)')

        label_mainscale = wx.StaticText(self.panel,  label="Mainscale")
        self.cb_mainscale = wx.ComboBox(self.panel,  0, choices=main_scale_scheme, style=wx.TE_PROCESS_ENTER | wx.CB_READONLY)
        self.cb_mainscale.Bind(wx.EVT_COMBOBOX, self.select_mainscale)

        scales = Scale.scale_patterns.keys()
        scales.sort()
        label_scale = wx.StaticText(self.panel,  label="Scale")
        self.cb_scale = wx.ComboBox(self.panel,  0, choices=scales, style=wx.TE_PROCESS_ENTER | wx.CB_READONLY)
        self.cb_scale.Bind(wx.EVT_COMBOBOX, self.select_scale)

        label_mode = wx.StaticText(self.panel,  label="Mode")
        self.cb_mode = wx.ComboBox(self.panel,  0, choices=[str(i) for i in range(12)], style=wx.TE_PROCESS_ENTER | wx.CB_READONLY)
        self.cb_mode.Bind(wx.EVT_COMBOBOX, self.select_mode)

        label_key = wx.StaticText(self.panel, label="Root note")
        self.cb_key = wx.ComboBox(self.panel,  0, choices=Scale.get_root_notes(), style=wx.TE_PROCESS_ENTER | wx.CB_READONLY)
        self.cb_key.Bind(wx.EVT_COMBOBOX, self.select_key)
        self.cb_key.SetSelection(3*12)  # set default selection to first C4

        label_pattern = wx.StaticText(self.panel, label="Pad layout")
        mpat = melody_pad_pattern.keys()
        mpat.sort()
        self.cb_pad_pattern = wx.ComboBox(self.panel,  0, choices=mpat, style=wx.TE_PROCESS_ENTER | wx.CB_READONLY)
        self.cb_pad_pattern.Bind(wx.EVT_COMBOBOX, self.select_pad_pattern)

        horizontal_box_sizer = wx.BoxSizer(wx.HORIZONTAL)
        setButton = wx.Button(self.panel, label='set')
        closeButton = wx.Button(self.panel, label='close')
        setButton.Bind(wx.EVT_BUTTON, self.OnOk)
        closeButton.Bind(wx.EVT_BUTTON, self.OnClose)

        horizontal_box_sizer.Add(setButton)
        horizontal_box_sizer.Add(closeButton, flag=wx.LEFT, border=5)

        fgs = wx.FlexGridSizer(7, 2, 9, 10)

        fgs.AddMany([(label_layer, 1, wx.EXPAND), (self.cb_layer, 1, wx.EXPAND),
                     (label_instrument, 1, wx.EXPAND), (self.cb_instrument, 1, wx.EXPAND),
                     (label_mainscale, 1, wx.EXPAND), (self.cb_mainscale, 1, wx.EXPAND),
                     (label_scale, 1, wx.EXPAND), (self.cb_scale, 1, wx.EXPAND),
                     (label_mode, 1, wx.EXPAND), (self.cb_mode, 1, wx.EXPAND),
                     (label_key, 1, wx.EXPAND), (self.cb_key, 1, wx.EXPAND),
                     (label_pattern, 1, wx.EXPAND), (self.cb_pad_pattern, 1, wx.EXPAND)
                     ])

        self.result_grid = gridlib.Grid(self.panel)
        self.result_grid.CreateGrid(17, 4)
        self.result_grid.SetColSize(0, 200)
        self.result_grid.SetColLabelValue(0, 'instrument')
        self.result_grid.SetColLabelValue(1, 'note')
        self.result_grid.SetColLabelValue(2, 'cents')
        self.result_grid.SetColLabelValue(3, 'pan')

        top_sizer.Add(self.result_grid, proportion=1, flag=wx.ALL | wx.EXPAND, border=15)
        top_sizer.Add(fgs, proportion=1, flag=wx.ALL | wx.EXPAND, border=15)
        top_sizer.Add(horizontal_box_sizer, proportion=1, flag=wx.ALL | wx.EXPAND, border=15)
        self.panel.SetSizer(top_sizer)
        self.select_pad_pattern(None)

    def copy_current_selection_to_result_grid(self, event):
        if self.cb_scale.GetSelection() == -1:
            return
        layer = self.cb_layer.GetStringSelection()
        instrument = self.cb_instrument.GetStringSelection()
        pad_pattern = self.cb_pad_pattern.GetStringSelection()
        note_count = len(melody_pad_pattern[pad_pattern])
        scale_name = self.cb_scale.GetStringSelection()
        first_note = Scale.get_height_of_note(self.cb_key.GetStringSelection())
        mode = int(self.cb_mode.GetStringSelection())
        scale = Scale.get_scale(instrument, first_note, note_count, scale_name, mode=mode)
        for i in range(0, 17):
            self.result_grid.SetCellValue(i, 0, "")
            self.result_grid.SetCellValue(i, 1, "")
            self.result_grid.SetCellValue(i, 2, "")
            self.result_grid.SetCellBackgroundColour(i, 1, wx.WHITE)
        for i in range(len(scale)):
            index = i
            self.result_grid.SetCellValue(index, 0, get_instrument_name(scale[i][0]))
            if abs(scale[i][1]) > 2400:
                self.result_grid.SetCellBackgroundColour(index, 1, wx.RED)
            else:
                self.result_grid.SetCellBackgroundColour(index, 1, wx.WHITE)
            pitch = scale[i][1] + get_instrument_pitch(scale[i][0])
            real_note = Scale.get_note_name(int((pitch+50) / 100))

            self.result_grid.SetCellValue(index, 1, real_note)
            self.result_grid.SetCellValue(index, 2, str(scale[i][1]))

    def show_result(self):
        self.copy_current_selection_to_result_grid(None)

    def select_mainscale(self, event):
        mainscale_index = self.cb_mainscale.GetSelection()
        if mainscale_index == 0:
            scales = Scale.scale_patterns.keys()
            scales.sort()
        else:
            notes = 4+(mainscale_index-1)/2
            l_of_scales = list_of_scales_with_n_notes(notes)
            scales = []
            for sc in l_of_scales:
                if mainscale_index % 2 == 0:
                    if sc[4][len(sc[4])-1] == 2.0:
                        scales.append(sc[1])
                if mainscale_index % 2 == 1:
                    if sc[4][len(sc[4]) - 1] != 2.0:
                        scales.append(sc[1])
        self.cb_scale.Clear()
        self.cb_scale.AppendItems(scales)
        self.copy_current_selection_to_result_grid(None)

    def select_scale(self, event):
        self.copy_current_selection_to_result_grid(None)

    def select_mode(self, event):
        self.copy_current_selection_to_result_grid(None)

    def select_pad_pattern(self, event):
        for i in range(len(Semantics.pad_names)):
            self.result_grid.SetCellEditor(2, i, gridlib.GridCellNumberEditor(-2400, 2400))
            self.result_grid.SetCellEditor(3, i, gridlib.GridCellNumberEditor(-15, 15))
            self.result_grid.SetRowLabelValue(i, "")

        pad_pattern = self.cb_pad_pattern.GetStringSelection()
        current_pattern = melody_pad_pattern[pad_pattern]

        for i in range(len(current_pattern)):
            self.result_grid.SetRowLabelValue(i, Semantics.pad_names[current_pattern[i]])
        self.copy_current_selection_to_result_grid(None)

    def select_key(self, event):
        self.copy_current_selection_to_result_grid(None)

    def select_instrument(self, event):
        self.copy_current_selection_to_result_grid(None)

    def OnOk(self, e):
        print("layer=" + self.cb_layer.GetStringSelection())
        if self.cb_layer.GetStringSelection() == 'Instrument B':
            layer = 1
        else:
            layer = 0
        instrument = self.cb_instrument.GetStringSelection()
        pad_pattern = self.cb_pad_pattern.GetStringSelection()
        current_pattern = melody_pad_pattern[pad_pattern]
        scale_name = self.cb_scale.GetStringSelection()
        first_note = int(Scale.get_height_of_note(self.cb_key.GetStringSelection()))
        mode = int(self.cb_mode.GetStringSelection())
        self.hpd.apply_scale(layer, instrument, scale_name, mode, first_note, int(self.current_kit), current_pattern)
        self.Close()
        self.Destroy()

    def OnClose(self, e):
        self.Close()
        self.Destroy()





from memoryops import MemoryOp

NAME_INDEX = 2
SUBNAME_INDEX = 14
KIT_MEMSIZE = 224

VOL_INDEX = 30
HH_VOL_INDEX = 31
BALANCE_INDEX = 67
PAD_SENSITIVITY = 55

class Kit:
    def __init__(self, memory_block):
        self.memory_block = memory_block

    def main_name(self):
        return MemoryOp.get_string(self.memory_block, NAME_INDEX, 12)

    def sub_name(self):
        return MemoryOp.get_string(self.memory_block, SUBNAME_INDEX, 16)

    def get_volume(self):
        return MemoryOp.get_unsigned_int8(self.memory_block, VOL_INDEX)

    def get_hh_volume(self):
        return MemoryOp.get_unsigned_int8(self.memory_block, HH_VOL_INDEX)

    def get_balance(self):
        return MemoryOp.get_int8(self.memory_block, BALANCE_INDEX)

    def get_pad_sensitvity(self):
        return MemoryOp.get_int8(self.memory_block, PAD_SENSITIVITY)

    def save(self, fh):
        fh.write(self.memory_block)

    def load(self, fh):
        self.memory_block = fh.read(KIT_MEMSIZE)


class Kits:
    def __init__(self, memory_block):
        self.memory_block = memory_block
        self.kits = []
        for i in range(200):
            slice_block = self.memory_block[KIT_MEMSIZE*i:KIT_MEMSIZE*(i+1)]
            self.kits.append(Kit(slice_block))

    def get_list_of_kits(self):
        res = []
        for i in range(200):
            res.append(str(i+1) + " " + self.kits[i].main_name().strip())
        return res

    def get_kit(self, index):
        return self.kits[index]






# coding=UTF-8

import os
from setuptools import setup, find_packages
from codecs import open
from os import path


long_description = 'Raumfeld controlled by python scripts'
here = path.abspath(path.dirname(__file__))
s = path.join(here, 'README.rst')

if os.path.exists(s):
    long_description = open('README.rst', 'r', encoding='utf8').read()
else:
    print("cant open readme.rst")

setup(
    name='hpd20',
    version='0.0.9',
    author='Jürgen Schwietering',
    author_email='scjurgen@yahoo.com',
    description='hpd-20 simple patch editor and librarian',
    long_description=long_description,
    license='MIT',
    keywords=['roland', 'handsonic', 'hpd20', 'hpd-20', 'percussion', 'editor', 'librarian', 'kit', 'pad'],
    url='http://github.com/scjurgen/hpd-20',
    packages=['hpd20', ],
    include_package_data=True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Other Environment',
        'Intended Audience :: End Users/Desktop',
        'Topic :: Software Development :: Build Tools',
        'Topic :: Multimedia :: Sound/Audio :: Editors',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Programming Language :: Python :: 2.7',
    ],
    #py_modules=['hpd20'],
    # https://packaging.python.org/en/latest/requirements.html
    #install_requires=['wx'],
    install_requires=['ConfigParser',],
    #packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    entry_points={
        'console_scripts': [
            'hpd20-ui=hpd20.hpd20wx:run_main',
            'hpd20-cli=hpd20.hpd20:run_main'
        ],
    }
)



#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys


def read_scale(file_name):
    fh = file(file_name, "r")
    text = fh.read()
    lines = text.splitlines()
    state = 0
    items = [1.0]
    items_org = ['1/1']
    for line in lines:
        if len(line):
            line = line.strip()
            if line[0] == '!':
                continue
            if state == 0:
                comment = line
                state = 1
            elif state == 1:
                count = int(line)
                state = 2
            elif state == 2:
                items_org.append(line)
                ratio = line.split('/')
                if len(ratio) == 2:
                    value = float(ratio[0])/float(ratio[1])
                else:
                    value = float(line)
                items.append(value)
    print ("    ['"+file_name+"',");
    print ("        '"+comment+"',");
    print ("        "+str(count) + ",");
    print ("        "+str(items_org));
    print ("        "+str(items));
    print ("    ],")
    return [file_name, comment, count+1, items_org, items]

if __name__ == "__main__":

    for index, item in enumerate(sys.argv[1:]):
        __ = read_scale(sys.argv[index+1])
